## OSVVM Project Authors - The people and/or organizations who own the copyrights

#### [SynthWorks](https://SynthWorks.com)
* Represented by Jim Lewis
  * Technical/Project lead
  * Maintainer / Contributor
  * email: jim (at) synthworks.com

#### [Patrick Lehmann](https://opensource.ieee.org/patrick.lehmann)
* Maintainer / Contributor

#### [Rob Gaddi](https://opensource.ieee.org/)
* Contributor

#### [Lars Asplund](https://opensource.ieee.org/)
* Contributor

## Participating  
The OSVVM project welcomes your participation with either 
issue reports or pull requests.
For details on [how to participate see](https://opensource.ieee.org/osvvm/OsvvmLibraries/-/blob/master/CONTRIBUTING.md)

You can find the project
[Contributors here](CONTRIBUTORS.md).



#### Copyright and License
Copyright (C) 2020 by [OSVVM Authors](AUTHORS.md)   

This file is part of OSVVM.

    Licensed under Apache License, Version 2.0 (the "License")
    You may not use this file except in compliance with the License.
    You may obtain a copy of the License at

  [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

